.. _main:

###########
Champollion
###########

Sphinx extension which provides an automatic way to document javascript code.

.. toctree::
    :maxdepth: 1

    introduction
    installing
    using
    documenting_javascript
    directive
    configuration
    api_reference/index
    release_notes
    glossary

******************
Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
